@@ -17,20 +17,22 @@
  */
 package org.apache.tools.ant.taskdefs.optional.junit;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-
 import java.io.OutputStream;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 
+import org.apache.tools.ant.BuildException;
+import org.junit.Test;
+
 import junit.framework.AssertionFailedError;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.tools.ant.BuildException;
-import org.junit.Test;
+import static org.hamcrest.Matchers.containsString;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertThat;
+import static org.junit.Assert.assertTrue;
 
 /**
  * Small testcase for the runner, tests are very very very basics.
@@ -54,7 +56,7 @@ public class JUnitTestRunnerTest {
         runner.run();
         String error = runner.getFormatter().getError();
         // might be FAILURES or ERRORS depending on JUnit version?
-        assertTrue(error, runner.getRetCode() != JUnitTestRunner.SUCCESS);
+        assertNotEquals(error, JUnitTestRunner.SUCCESS, runner.getRetCode());
     }
 
     // check that having no suite generates no errors
@@ -80,7 +82,7 @@ public class JUnitTestRunnerTest {
         runner.run();
         String error = runner.getFormatter().getError();
         assertEquals(error, JUnitTestRunner.ERRORS, runner.getRetCode());
-        assertTrue(error, error.contains("thrown on purpose"));
+        assertThat(error, error, containsString("thrown on purpose"));
     }
 
     // check that something which is not a testcase generates no errors
@@ -91,10 +93,8 @@ public class JUnitTestRunnerTest {
         runner.run();
         // On junit3 this is a FAILURE, on junit4 this is an ERROR
         int ret = runner.getRetCode();
-
-        if (ret != JUnitTestRunner.FAILURES && ret != JUnitTestRunner.ERRORS) {
-            fail("Unexpected result " + ret + " from junit runner");
-        }
+        assertTrue("Unexpected result " + ret + " from junit runner",
+                ret == JUnitTestRunner.FAILURES || ret == JUnitTestRunner.ERRORS);
         // JUnit3 test
         //assertEquals(runner.getFormatter().getError(), JUnitTestRunner.FAILURES, runner.getRetCode());
     }
@@ -121,11 +121,10 @@ public class JUnitTestRunnerTest {
     public void testStaticInitializerErrorTestCase() {
         TestRunner runner = createRunner(StaticInitializerErrorTestCase.class);
         runner.run();
-        // On junit3 this is a FAILURE, on junit4 this is an ERROR
+        // For JUnit 3 this is a FAILURE, for JUnit 4 this is an ERROR
         int ret = runner.getRetCode();
-        if (ret != JUnitTestRunner.FAILURES && ret != JUnitTestRunner.ERRORS) {
-            fail("Unexpected result " + ret + " from junit runner");
-        }
+        assertTrue("Unexpected result " + ret + " from junit runner",
+                ret == JUnitTestRunner.FAILURES || ret == JUnitTestRunner.ERRORS);
     }
 
     // check that an exception in the constructor is noticed
@@ -133,15 +132,14 @@ public class JUnitTestRunnerTest {
     public void testInvalidTestCase() {
         TestRunner runner = createRunner(InvalidTestCase.class);
         runner.run();
-        // On junit3 this is a FAILURE, on junit4 this is an ERROR
+        // For JUnit 3 this is a FAILURE, for JUnit 4 this is an ERROR
         int ret = runner.getRetCode();
-        if (ret != JUnitTestRunner.FAILURES && ret != JUnitTestRunner.ERRORS) {
-            fail("Unexpected result " + ret + " from junit runner");
-        }
+        assertTrue("Unexpected result " + ret + " from junit runner",
+                ret == JUnitTestRunner.FAILURES || ret == JUnitTestRunner.ERRORS);
         // JUNIT3 test
         //assertEquals(error, JUnitTestRunner.FAILURES, runner.getRetCode());
         //@fixme as of now does not report the original stacktrace.
-        //assertTrue(error, error.indexOf("thrown on purpose") != -1);
+        //assertThat(error, error, containsString("thrown on purpose"));
     }
 
     // check that JUnit 4 synthetic AssertionFailedError gets message and cause from AssertionError
@@ -309,9 +307,7 @@ public class JUnitTestRunnerTest {
     public static class AssertionErrorTest {
         @Test
         public void throwsAssertionError() {
-            AssertionError assertionError = new AssertionError("failure message");
-            assertionError.initCause(new RuntimeException("cause message"));
-            throw assertionError;
+            throw new AssertionError("failure message", new RuntimeException("cause message"));
         }
     }
 }
