@@ -19,6 +19,7 @@ package org.apache.tools.ant.taskdefs.optional.vss;
 
 import java.io.File;
 import java.text.SimpleDateFormat;
+import java.util.Arrays;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.TimeZone;
@@ -34,9 +35,11 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 /**
  *  Testcase to ensure that command line generation and required attributes are correct.
@@ -64,6 +67,9 @@ public class MSVSSTest implements MSVSSConstants {
     public BuildFileRule buildRule = new BuildFileRule();
     private Project project;
 
+    @Rule
+    public ExpectedException thrown = ExpectedException.none();
+
     @Before
     public void setUp() {
         project = new Project();
@@ -114,7 +120,7 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testGetExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vssget.1", "some cause", "vsspath attribute must be set!");
+        expectSpecificBuildException("vssget.1", "vsspath attribute must be set!");
     }
 
     /**  Tests Label commandline generation.  */
@@ -167,8 +173,8 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testLabelExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vsslabel.1", "some cause", "vsspath attribute must be set!");
-        expectSpecificBuildException("vsslabel.2", "some cause", "label attribute must be set!");
+        expectSpecificBuildException("vsslabel.1", "vsspath attribute must be set!");
+        expectSpecificBuildException("vsslabel.2", "label attribute must be set!");
     }
 
     /**  Tests VSSHistory commandline generation with from label.  */
@@ -261,17 +267,13 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testHistoryExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vsshistory.1", "some cause", "vsspath attribute must be set!");
+        expectSpecificBuildException("vsshistory.1", "vsspath attribute must be set!");
     }
 
-    private void expectSpecificBuildException(String target, String failMessage,
-                                              String exceptionMessage) {
-        try {
-            buildRule.executeTarget(target);
-            fail(failMessage);
-        } catch (BuildException ex) {
-            assertEquals(exceptionMessage, ex.getMessage());
-        }
+    private void expectSpecificBuildException(String target, String exceptionMessage) {
+        thrown.expect(BuildException.class);
+        thrown.expectMessage(exceptionMessage);
+        buildRule.executeTarget(target);
     }
 
     /**  Tests CheckIn commandline generation.  */
@@ -301,7 +303,7 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testCheckinExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vsscheckin.1", "some cause", "vsspath attribute must be set!");
+        expectSpecificBuildException("vsscheckin.1", "vsspath attribute must be set!");
     }
 
     /**  Tests CheckOut commandline generation.  */
@@ -337,8 +339,8 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testCheckoutExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vsscheckout.1", "some cause", "vsspath attribute must be set!");
-        expectSpecificBuildException("vsscheckout.2", "some cause", "blah is not a legal value for this attribute");
+        expectSpecificBuildException("vsscheckout.1", "vsspath attribute must be set!");
+        expectSpecificBuildException("vsscheckout.2", "blah is not a legal value for this attribute");
     }
 
     /**  Tests Add commandline generation.  */
@@ -370,7 +372,7 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testAddExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vssadd.1", "some cause", "localPath attribute must be set!");
+        expectSpecificBuildException("vssadd.1", "localPath attribute must be set!");
     }
 
     /**  Tests CP commandline generation.  */
@@ -397,7 +399,7 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testCpExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vsscp.1", "some cause", "vsspath attribute must be set!");
+        expectSpecificBuildException("vsscp.1", "vsspath attribute must be set!");
     }
 
     /**  Tests Create commandline generation.  */
@@ -428,7 +430,7 @@ public class MSVSSTest implements MSVSSConstants {
     @Test
     public void testCreateExceptions() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/vss/vss.xml");
-        expectSpecificBuildException("vsscreate.1", "some cause", "vsspath attribute must be set!");
+        expectSpecificBuildException("vsscreate.1", "vsspath attribute must be set!");
     }
 
     /**
@@ -444,31 +446,20 @@ public class MSVSSTest implements MSVSSConstants {
         int testIndex = 0;
 
         while (testIndex < testLength) {
-            try {
-                if (sGeneratedCmdLine[genIndex].equals("")) {
-                    genIndex++;
-                    continue;
-                }
-                assertEquals("arg # " + testIndex,
-                        sTestCmdLine[testIndex],
-                        sGeneratedCmdLine[genIndex]);
-                testIndex++;
+            if (sGeneratedCmdLine[genIndex].isEmpty()) {
                 genIndex++;
-            } catch (ArrayIndexOutOfBoundsException aioob) {
-                fail("missing arg " + sTestCmdLine[testIndex]);
+                continue;
             }
+            assertTrue("missing arg " + sTestCmdLine[testIndex], genIndex < genLength);
+            assertEquals("arg # " + testIndex,
+                    sTestCmdLine[testIndex], sGeneratedCmdLine[genIndex]);
+            testIndex++;
+            genIndex++;
         }
 
         // Count the number of empty strings
-        int cnt = 0;
-        for (String argument : sGeneratedCmdLine) {
-            if (argument.equals("")) {
-                cnt++;
-            }
-        }
-        if (genLength - cnt > sTestCmdLine.length) {
-            // We have extra elements
-            fail("extra args");
-        }
+        int cnt = (int) Arrays.stream(sGeneratedCmdLine).filter(String::isEmpty).count();
+        // We have extra elements
+        assertFalse("extra args", genLength - cnt > sTestCmdLine.length);
     }
 }
